@@ -46,7 +46,8 @@ class Request(object):
     Attributes:
         method: HTTP method requested (e.g., GET, POST, etc.)
         path: Path portion of the request URL (not including query string).
-        query_string: Query string portion of the request URL.
+        query_string: Query string portion of the request URL, without
+            the preceding '?' character.
         stream: Stream-like object for reading the body of the request, if any.
 
     """
@@ -79,7 +80,16 @@ class Request(object):
         self.stream = env['wsgi.input']
 
         self.method = env['REQUEST_METHOD']
-        self.path = env['PATH_INFO'] or '/'
+
+        # Normalize path
+        path = env['PATH_INFO']
+        if path:
+            if len(path) != 1 and path.endswith('/'):
+                self.path = path[:-1]
+            else:
+                self.path = path
+        else:
+            self.path = '/'
 
         # QUERY_STRING isn't required to be in env, so let's check
         # PERF: if...in is faster than using env.get(...)
